<?php

declare(strict_types=1);

return [
    'meta' => [
        "default_divider" => env('APP_DEFAULT_META_DIVIDE', '|'),
        "default_title" => env('APP_DEFAULT_META_TITLE', 'IO Dashboard'),
    ],
];