<?php

namespace apexl\Io\modules\display\pages;

use apexl\Io\modules\display\regions\NoUIContentRegion;
use apexl\Io\modules\display\regions\PageContentRegion;

class noUIiframeFlow extends blankPage
{
    protected function buildRegions(): void
    {
        $this->globalRegion = (new PageContentRegion())->addWrapperClass('nouiiframe-flow');
        $this->globalRegion->addRegions([
            new NoUIContentRegion([

            ])
        ]);
    }
}
