<?php

namespace apexl\Io\modules\display\regions;

use apexl\Io\modules\display\components\ThePageContent;
use apexl\Io\modules\display\includes\region;

/**
 * @type region
 * Class PageContentRegion
 * @package apexl\Io\modules\display\regions
 */
class PageContentRegion extends region
{
    public function setRegionWrapper(): void
    {
        $this->regionComponent = $this->componentFactory->make(ThePageContent::class);
    }
}
