<?php

namespace apexl\Io\modules\display\Dtos;

use apexl\dto\Dto;

final readonly class PageDataDto extends Dto
{
    public function __construct(
        public array $metadata,
        public array $global,
        public array $components,
    ) {}
}
